@@ -200,6 +200,7 @@ def process_line(calc_line, local_ns):
     # Handle manually inserted line breaks placed in the line by the user
     description = description.replace('\\\\', '} \\\\ \\textsf{')
     equation = equation.replace('\\\\', '')
+    reference = reference.replace('\\\\', '} \\\\ \\textsf{')
     
     # Turn off pretty printing momentarily while we prepare a Python expression for the value
     ureg.default_format = '~'
@@ -321,7 +322,8 @@ def process_line(calc_line, local_ns):
     # There will be a double equals sign if the equation is not being displayed
     latex_text = latex_text.replace('==', '=')
     
-    print(latex_text)
+    # Uncomment the next line to view the raw latex output while debugging
+    # print(latex_text)
 
     return latex_text
 
